@@ -100,6 +100,7 @@ class DeepROC(FullROC):
         from deeproc.Helpers.DeepROCFunctions import concordant_partial_AUC
         from deeproc.Helpers.DeepROCFunctions import discrete_partial_roc_measures
         from deeproc.Helpers.DeepROCFunctions import partial_area_index_proxy
+        from deeproc.Helpers.DeepROCFunctions import standardized_partial_area_proxy
         from deeproc.Helpers.DeepROCFunctions import areEpsilonEqual
         from deeproc.Helpers.DeepROCFunctions import showConcordanceMatrixInfo
         from deeproc.Helpers.DeepROCFunctions import showCmeasures
@@ -301,12 +302,18 @@ class DeepROC(FullROC):
     def analyze(self, forFolds=False, verbose=False):
         from deeproc.Helpers.DeepROCFunctions import areEpsilonEqual
 
-        measure_dict = []
         if self.groupsArePerfectCoveringSet:
             Ci_sum, AUCi_sum, pAUC_sum, pAUCx_sum = [0, 0, 0, 0]
             allIterationsPassed = True
-        # endif
-        numgroups = len(self.groups)
+        #endif
+
+        if forFolds:
+            # prior to analyzeGroup, which analyzes the mean ROC curve we need to...
+            self.computeMeanROC()
+        #endif
+
+        numgroups    = len(self.groups)
+        measure_dict = []
         for i in range(0, numgroups):
             print(f'\nGroup {i + 1}:')
             iterationPassed, iteration_dict = self.analyzeGroup(i, showData=True, forFolds=forFolds, quiet=False,
